diff mbox series

[bug#63176,09/10] gnu: python-pytest-astropy: Update to 0.10.0.

Message ID 20230429170840.105227-9-felgru@posteo.net
State New
Headers show
Series Fix some broken python packages. | expand

Commit Message

Felix Gruber April 29, 2023, 5:08 p.m. UTC
* gnu/packages/python-check.scm (python-pytest-astropy): Update to 0.10.0.
[build-system]: Use pyproject-build-system.
[arguments]: Remove broken version check for pytest-remotedata.
---
 gnu/packages/python-check.scm | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)
diff mbox series

Patch

diff --git a/gnu/packages/python-check.scm b/gnu/packages/python-check.scm
index 160d30179b..84d968e061 100644
--- a/gnu/packages/python-check.scm
+++ b/gnu/packages/python-check.scm
@@ -517,17 +517,19 @@  (define-public python-pytest-astropy
        (uri (pypi-uri "pytest-astropy" version))
        (sha256
         (base32 "04g2rh261s3s6ym8mwi4iv2a6anbgwvwzcvkyilfck6yxrncdqw5"))))
-    (build-system python-build-system)
+    (build-system pyproject-build-system)
     (arguments
      `(#:tests? #f ; there are no tests
        #:phases
        (modify-phases %standard-phases
          ;; There is a bug somewhere that makes pytest-filter-subpackage appear
          ;; as version 0.0.0 to setup.py.  Remove it from the requirements.
          (add-after 'unpack 'remove-requirement
            (lambda _
              (substitute* "setup.cfg"
-               ((".*pytest-filter-subpackage.*") "")))))))
+               ((".*pytest-filter-subpackage.*") "")
+               ((".*pytest-remotedata.*") "")))))))
     (native-inputs
      (list python-attrs python-pytest-mock python-setuptools-scm))
     (propagated-inputs
@@ -517,17 +517,19 @@  (define-public python-pytest-astropy
        #:phases
        (modify-phases %standard-phases
-         ;; There is a bug somewhere that makes pytest-filter-subpackage appear
-         ;; as version 0.0.0 to setup.py.  Remove it from the requirements.
+         ;; There is a bug somewhere that makes pytest-filter-subpackage
+         ;; and pytest-remotedata appear as version 0.0.0 to setup.py.
+         ;; Remove them from the requirements.
          (add-after 'unpack 'remove-requirement
            (lambda _